@@ -1,6 +1,10 @@
 import torch
 from .preprocessing import preprocess_tweet
-from transformers import AutoTokenizer, AutoModelForSequenceClassification
+from transformers import (
+    AutoTokenizer, AutoModelForSequenceClassification, DataCollatorWithPadding,
+    Trainer, TrainingArguments
+)
+from datasets import Dataset
 from torch.nn import functional as F
 
 models = {
@@ -29,12 +33,11 @@ class BaseOutput:
     """
     Base class for classification output
     """
-    def __init__(self, sentence, idx, probas):
+    def __init__(self, sentence, probas):
         """
         Constructor
         """
         self.sentence = sentence
-        self.idx = idx
         self.probas = probas
         self.output = max(probas.items(), key=lambda x: x[1])[0]
 
@@ -58,26 +61,96 @@ class Analyzer:
     """
     Wrapper to use sentiment analysis models as black-box
     """
-    def __init__(self, model_name, preprocessing_args={}):
+    def __init__(self, model_name, preprocessing_args={}, batch_size=32):
         """
         Constructor for SentimentAnalyzer class
+
+        Arguments:
+
+        model_name: str or path
+            Model name or
         """
         self.tokenizer = AutoTokenizer.from_pretrained(model_name)
+        self.tokenizer.model_max_length=128
         self.model = AutoModelForSequenceClassification.from_pretrained(model_name)
         self.id2label = self.model.config.id2label
         self.preprocessing_args = preprocessing_args
+        self.batch_size = batch_size
 
-    def predict(self, sentence):
+        self.eval_trainer = Trainer(
+            model=self.model,
+            args=TrainingArguments(
+                output_dir=".",
+                per_device_eval_batch_size=batch_size,
+            ),
+            data_collator=DataCollatorWithPadding(self.tokenizer, padding="longest"),
+        )
+
+    def _tokenize(self, batch):
+        return self.tokenizer(
+            batch["text"], padding=False, truncation=True
+        )
+
+    def _predict_single(self, sentence):
         """
-        Return most likely class for the sentence
+        Predict single
+
+        Do it this way (without creating dataset) to make it faster
         """
+        device = self.eval_trainer.args.device
         sentence = preprocess_tweet(sentence, **self.preprocessing_args)
-        idx = torch.LongTensor(self.tokenizer.encode(sentence)).view(1, -1)
+        idx = torch.LongTensor(
+            self.tokenizer.encode(
+                sentence, truncation=True,
+                max_length=self.tokenizer.model_max_length,
+            )
+        ).view(1, -1).to(device)
         output = self.model(idx)
         probs = F.softmax(output.logits, dim=1).view(-1)
         probas = {self.id2label[i]:probs[i].item() for i in self.id2label}
 
-        return self.__class__.output_class(sentence, idx=idx, probas=probas)
+        return self.output_class(sentence, probas=probas)
+
+
+    def predict(self, inputs):
+        """
+        Return most likely class for the sentence
+
+        Arguments:
+        ----------
+        inputs: string or list of strings
+            A single or a list of sentences to be predicted
+
+        Returns:
+        --------
+            List or single output with probabilities
+        """
+        if isinstance(inputs, str):
+            return self._predict_single(inputs)
+
+
+        sentences = [
+            preprocess_tweet(sent, **self.preprocessing_args) for sent in inputs
+        ]
+        dataset = Dataset.from_dict({"text": sentences})
+        dataset = dataset.map(self._tokenize, batched=True, batch_size=self.batch_size)
+
+        print(len(dataset))
+
+        output = self.eval_trainer.predict(dataset)
+        logits = torch.tensor(output.predictions)
+
+        probs = F.softmax(logits, dim=1)
+
+        probas = [{
+            self.id2label[i]: probs[j][i].item()
+            for i in self.id2label
+        } for j in range(probs.shape[0])]
+
+
+        rets = [self.output_class(sent, prob) for sent, prob in zip(sentences, probas) ]
+
+        return rets
 
 
 
