@@ -1,11 +1,7 @@
 import emoji
 import re
 
-special_tokens = [
-    "[USER]",
-    "[HASHTAG]",
-    "[EMOJI]",
-]
+special_tokens = ["@usuario", "url", "hashtag", "emoji"]
 
 
 user_regex = re.compile(r"@[a-zA-Z0-9_]{0,15}")
@@ -39,7 +35,7 @@ emoji_regex = re.compile(r"\|([^\|]+)\|")
 def convert_emoji_to_text(x, emoji_wrapper="[EMOJI]"):
     """
     """
-    return f"{emoji_wrapper} " + " ".join(x.groups()[0].split("_")) + f" {emoji_wrapper}"
+    return f" {emoji_wrapper} " + " ".join(x.groups()[0].split("_")) + f" {emoji_wrapper} "
 
 
 replacements = {
@@ -102,8 +98,8 @@ laughter_conf = {
 
 
 def preprocess_tweet(
-    text, lang="es", user_token="[USER]", url_token="[URL]", preprocess_hashtags=True, hashtag_token=None,
-    demoji=True, shorten=3, normalize_laughter=True, emoji_wrapper="[EMOJI]"):
+    text, lang="es", user_token="@usuario", url_token="url", preprocess_hashtags=True, hashtag_token=None,
+    demoji=True, shorten=3, normalize_laughter=True, emoji_wrapper="emoji"):
     """
     Basic preprocessing
 
@@ -195,5 +191,4 @@ def preprocess_tweet(
             text
         )
 
-
-    return text
+    return text.strip()
